aboutsummaryrefslogtreecommitdiff
path: root/sway/input
diff options
context:
space:
mode:
Diffstat (limited to 'sway/input')
-rw-r--r--sway/input/cursor.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sway/input/cursor.c b/sway/input/cursor.c
index d10ba444..0d5b076b 100644
--- a/sway/input/cursor.c
+++ b/sway/input/cursor.c
@@ -99,8 +99,8 @@ struct sway_node *node_at_coords(
return NULL;
}
struct sway_output *output = wlr_output->data;
- if (!output || !output->configured) {
- // output is being destroyed or is being configured
+ if (!output || !output->enabled) {
+ // output is being destroyed or is being enabled
return NULL;
}
double ox = lx, oy = ly;